Skip to content

Tags

Updated: Mar 3, 2025

Represents a collection of IG Media objects in which your app user's Instagram professional account has been tagged by another Instagram user.

Creating

This operation is not supported.

Reading

GET /<IG_USER_ID>/tags

Returns a list of IG Media objects in which an IG User has been tagged by another Instagram user.

Limitations

Private IG Media objects will not be returned.

Requirements

TypeDescription
Access TokensUser
FeaturesNot applicable.
Permissionsinstagram_basic``instagram_manage_comments``pages_read_engagement If the token is from a User whose Page role was granted via the Business Manager, one of the following permissions is also required: ads_management or ads_read.
TasksThe app user must be able to perform appropriate Tasks on the Page based on the Permissions requested by the app.

Request Syntax

GET https://graph.facebook.com/<IG_USER_ID>/tags
  ?fields=<LIST_OF_FIELDS>
  &access_token=<ACCESS_TOKEN>

Query String Parameters

Include the following query string parameters to augment the request.

KeyValue
access_token Required StringThe app user's Instagram User Access Token.
fields Comma-separated listA comma-separated list of Fields and Edges you want included in the response. If omitted, default fields will be returned.

Fields

Use the fields query string parameter to specify fields you want included on any returned IG Media objects.

Edges

Use the fields query string parameter to specify Edges you want included on any returned IG Media objects.

Response

A JSON-formatted object containing IG Media objects.

{  
  "<FIELD>":"<VALUE>",  
  ...  
}

Pagination

This edge supports cursor-based pagination so the response will include before and after cursors if the response contains multiple pages of data. Unlike standard cursor-based pagination, however, the response will not include previous or next fields, so you will have to use the before and after cursors to construct previous and next query strings manually in order to page through the returned data set.

Sample Request

GET graph.facebook.com/17841405822304914/tags
    ?fields=id,username
    &access_token=EAADd...

Sample Response

{
  "data": [
    {
      "id": "18038...",
      "username": "keldo..."
    },
    {
      "id": "17930...",
      "username": "ashla..."
    },
    {
      "id": "17931...",
      "username": "jaypo..."
    }
  ]
}

Updating

This operation is not supported.

Deleting

This operation is not supported.

Unofficial mirror for reference/search purposes. All content originates from developers.facebook.com — see the source link at the top of each page. Machine-readable indexes: llms.txt · llms-full.txt · About